@@ -2,6 +2,7 @@
 
 import unittest
 from pytoxml import PyToXml
+from lxml import etree
 
 class TestPyToXml(unittest.TestCase):
     def test_simple_root(self):
@@ -32,15 +33,6 @@ class TestPyToXml(unittest.TestCase):
         p2x.encode()
         self.assertEqual(str(p2x), "<root><a><b>c</b></a></root>")
 
-    def test_sublclassed_dict_values(self):
-        class MyDict(dict):
-            pass
-        mydict = MyDict()
-        mydict["a"] = { "b": "c" }
-        p2x = PyToXml("root", mydict)
-        p2x.encode()
-        self.assertEqual(str(p2x), "<root><a><b>c</b></a></root>")
-
     def test_list_values(self):
         p2x = PyToXml("root", { "a": [1, 2] })
         p2x.encode()
@@ -80,5 +72,32 @@ class TestPyToXml(unittest.TestCase):
         p2x = PyToXml("root", { "unknown": Exception("Shouldn't serialise") })
         self.assertRaises(TypeError, p2x.encode)
 
+    def test_add_type_handler(self):
+        def temp_convertor(structure, document, name):
+            document.text = str(structure)
+
+        p2x = PyToXml("a", { "b": Exception("Should now serialise") })
+        p2x.add_type_handler(Exception, temp_convertor)
+        self.assertEqual(str(p2x.encode()), "<a><b>Should now serialise</b></a>")
+
+    def test_cdata_example(self):
+        class CData(object):
+            def __init__(self, string):
+                self.string = string
+
+            def __str__(self):
+                return self.string
+
+        def cdata_to_xml(structure, document, name):
+            document.text = etree.CDATA(str(structure))
+
+        cdata = CData("<xml>is pretty</horrible>")
+
+        p2x = PyToXml("a", { "b": cdata } )
+        p2x.add_type_handler(CData, cdata_to_xml)
+
+        self.assertEqual(str(p2x.encode()),
+                         "<a><b><![CDATA[<xml>is pretty</horrible>]]></b></a>")
+
 if __name__ == '__main__':
     unittest.main()
